aboutsummaryrefslogtreecommitdiff
path: root/lib/urldata.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/urldata.h')
-rw-r--r--lib/urldata.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/lib/urldata.h b/lib/urldata.h
index 595e797b7..0271d266b 100644
--- a/lib/urldata.h
+++ b/lib/urldata.h
@@ -1468,7 +1468,7 @@ enum dupstring {
STRING_NETRC_FILE, /* if not NULL, use this instead of trying to find
$HOME/.netrc */
STRING_PROXY, /* proxy to use */
- STRING_SOCKS_PROXY, /* socks proxy to use */
+ STRING_PRE_PROXY, /* pre socks proxy to use */
STRING_SET_RANGE, /* range, if used */
STRING_SET_REFERER, /* custom string for the HTTP referer field */
STRING_SET_URL, /* what original URL to work on */